@@ -52,9 +52,6 @@
 #define APP_WINDOW_HEIGHT 400 // ~hildonwindow workspace
 
 static GtkWidget *app_window;
-static GtkWidget *player_window;
-static GtkWidget *loader_window;
-static GtkWidget *image_window;
 
 static GtkWidget *status_text=NULL;
 
@@ -1478,12 +1475,6 @@ static void output_mode_changed (GtkToggleButton *togglebutton,
 }
 
 
-static void
-show_window (gpointer *window)
-{
-  printf("show window %p!\n", window);
-  gtk_widget_show (GTK_WIDGET(window));
-}
 
 int main (int argc, char **argv)
 {
@@ -1509,11 +1500,6 @@ int main (int argc, char **argv)
     *loader_label,
     *image_label,
 
-
-    *stack_player_button,
-    *stack_loader_button,
-    *stack_image_button,
-
     *player_page,
     *loader_page,
     *config_page,
@@ -1682,10 +1668,6 @@ int main (int argc, char **argv)
   g_object_ref (config_page);
 
 
-  /* force notebook for arm device */
-#define NOTEBOOK
-
-
 #ifdef NOTEBOOK
   mother_container = gtk_notebook_new();
 
@@ -1701,47 +1683,6 @@ int main (int argc, char **argv)
 
   g_signal_connect (G_OBJECT (mother_container), "switch-page",
 		    G_CALLBACK (page_changed), image_page);
-#else
-
-  //#define STACK
-#ifdef STACK
-  stack_player_button = create_huge_button("Player");
-  stack_loader_button = create_huge_button("Loader");
-  stack_image_button = create_huge_button("Slideshow");
-
-#define UI_PAD 64
-  mother_container = gtk_hbox_new (TRUE, UI_PAD);
-
-  gtk_box_pack_start (GTK_BOX(mother_container), stack_player_button, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX(mother_container), stack_loader_button, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX(mother_container), stack_image_button, FALSE, FALSE, 0);
-
-  player_window = hildon_stackable_window_new();
-  loader_window = hildon_stackable_window_new();
-  image_window  = hildon_stackable_window_new();
-
-
-  gtk_container_add (GTK_CONTAINER(player_window), player_page);
-  gtk_container_add (GTK_CONTAINER(loader_window), loader_page);
-  gtk_container_add (GTK_CONTAINER(image_window), image_page);
-
-  /*
-  hildon_program_add_window (program, HILDON_WINDOW (player_window));
-  hildon_program_add_window (program, HILDON_WINDOW (loader_window));
-  hildon_program_add_window (program, HILDON_WINDOW (image_window));
-  */
-
-  printf("player window pointer %p!\n", player_window);
-
-  g_signal_connect (G_OBJECT(stack_player_button), "clicked", G_CALLBACK (show_window), player_window);
-  g_signal_connect (G_OBJECT(stack_loader_button), "clicked", G_CALLBACK (show_window), loader_window);
-  g_signal_connect (G_OBJECT(stack_image_button),  "clicked", G_CALLBACK (show_window), image_window);
-
-
-#endif
-
-
-
 #endif
 
 
